package com.ajay.smshandler;

import android.Manifest;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;
import android.telephony.SmsManager;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.core.content.ContextCompat;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** SmshandlerPlugin */
public class SmshandlerPlugin implements FlutterPlugin, MethodCallHandler {

  private MethodChannel channel;

  private static Context context;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "smshandler");
    context = flutterPluginBinding.getApplicationContext();
    channel.setMethodCallHandler(this);
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "smshandler");
    context = registrar.context();
    channel.setMethodCallHandler(new SmshandlerPlugin());
  }

  @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP_MR1)
  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if(call.method.equals("sendSms")){

      String number = call.argument("number");
      String message = call.argument("data");
      int simId = call.argument("simId");

      if(checkSmsPermission(Manifest.permission.SEND_SMS)){
        SmsManager smsManager = SmsManager.getSmsManagerForSubscriptionId(simId);
        smsManager.sendTextMessage(number,null,message,null,null);
        result.success("SMS_SEND");
      } else {
        Log.d("010","PERMISSION_NOT_SET");
      }
    }
  }

  private Boolean checkSmsPermission(String permission) {
    int check = ContextCompat.checkSelfPermission(context,permission);
    return(check == PackageManager.PERMISSION_GRANTED);
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
